<?php

namespace Drupal\route_specific_breadcrumb\Breadcrumb;

use Drupal\Core\Breadcrumb\Breadcrumb;
use Drupal\Core\Breadcrumb\BreadcrumbBuilderInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Link;
use Drupal\route_specific_breadcrumb\Controller\ListRecordsController;
use Drupal\Core\Url;

/**
 * Class RouteSpecificBreadcrumbBuilder.
 */
class RouteSpecificBreadcrumbBuilder implements BreadcrumbBuilderInterface {

  /**
   * {@inheritdoc}
   */
  public function applies(RouteMatchInterface $attributes) {
    $db = \Drupal::database();
    $routeName = $attributes->getRouteName();
    $data = ListRecordsController::routeCheck($db, $routeName);
    if (isset($data->route) && ($data->route == $routeName)) {
      return $routeName;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function build(RouteMatchInterface $route_match) {
    $db = \Drupal::database();
    $data = ListRecordsController::routeCheck($db, $route_match->getRouteName());
    $routeName = $route_match->getRouteName();
    if ($data->route == $routeName) {
      $breadcrumb = new Breadcrumb();
      $description = unserialize($data->description);
      foreach ($description as $key => $value) {
        $url = Url::fromUri('internal:' . $value['link']);
        $project_link = Link::fromTextAndUrl($value['name'], $url);
        $breadcrumb->addLink($project_link);
      }
    }
    return $breadcrumb;
  }

}
